@@ -17,3 +17,8 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, see <http://www.gnu.org/licenses/>.
+
+__all__ = ['client', 'cachet']
+
+from pylls import client
+from pylls import cachet
