@@ -136,8 +136,8 @@ class Components(client.CachetAPIEndPoint):
         data['enabled'] = enabled
         return self._post('components', data=data)['data']
 
-    def update(self, component_id, name=None, status=None,
-               description=None, link=None, order=0, group_id=0, enabled=True):
+    def update(self, component_id, name=None, status=None, description=None,
+               link=None, order=None, group_id=None, enabled=True):
         """Update a component
 
         :param int component_id: Component ID
@@ -441,7 +441,7 @@ class MetricPoints(client.CachetAPIEndPoint):
         data = ApiParams()
         data['value'] = value
         data['timestamp'] = timestamp
-        return self._post('metrics/%s/points' % metric_id, data=data)
+        return self._post('metrics/%s/points' % metric_id, data=data)['data']
 
     def delete(self, metric_id, point_id):
         """Delete a Metric Point
